@@ -13,7 +13,7 @@ use 5.010001;
 
 no warnings qw( threads recursion uninitialized once );
 
-our $VERSION = '1.847';
+our $VERSION = '1.848';
 
 ## no critic (BuiltinFunctions::ProhibitStringyEval)
 ## no critic (Subroutines::ProhibitSubroutinePrototypes)
@@ -448,7 +448,7 @@ MCE::Shared - MCE extension for sharing data supporting threads and processes
 
 =head1 VERSION
 
-This document describes MCE::Shared version 1.847
+This document describes MCE::Shared version 1.848
 
 =head1 SYNOPSIS
 
@@ -876,6 +876,7 @@ process. The included C<MCE::Shared::Minidb> module provides optimized methods
 for working with hash of hashes C<HoH> and hash of arrays C<HoA>.
 
  use MCE::Shared;
+ use Data::Dumper;
 
  my $abc = MCE::Shared->minidb;
 
@@ -888,7 +889,7 @@ for working with hash of hashes C<HoH> and hash of arrays C<HoA>.
     }
  }
 
- _dump( $abc );
+ print Dumper( $abc->export ), "\n";
 
 For further reading, see L<MCE::Shared::Minidb>.
 
@@ -1036,12 +1037,12 @@ C<CDB_File> is given in the prior section.
 
 =back
 
+ BEGIN { @AnyDBM_File::ISA = qw( DB_File GDBM_File NDBM_File ODBM_File ); }
+
  use MCE::Shared;
  use Fcntl;
  use AnyDBM_File;
 
- BEGIN { @AnyDBM_File::ISA = qw( DB_File GDBM_File NDBM_File ODBM_File ); }
-
  tie my %h1, 'MCE::Shared', { module => 'AnyDBM_File' },
     'foo_a', O_CREAT|O_RDWR or die "open error: $!";
 
@@ -1160,6 +1161,8 @@ C<CDB_File> is given in the prior section.
  # Do not specify the 'str' option for Tie::(Array|Hash)::DBD.
  # Instead, see encoder-decoder methods described under Common API.
 
+ use DBD::SQLite;
+
  tie my @a1, 'MCE::Shared', { module => 'Tie::Array::DBD' },
     'dbi:SQLite:dbname=foo_a.db', {
        tbl => 't_tie_analysis',
@@ -1174,6 +1177,8 @@ C<CDB_File> is given in the prior section.
        fld => 'h_value'
     };
 
+ use DBD::CSV;
+
  tie my %h2, 'MCE::Shared', { module => 'Tie::Hash::DBD'},
     'dbi:CSV:f_dir=.;f_ext=.csv/r;csv_null=1;csv_decode_utf8=0', {
        tbl => 'mytable',
@@ -1186,8 +1191,11 @@ C<CDB_File> is given in the prior section.
 
  use JSON::XS ();
 
- tied(%ha2)->encoder( \&JSON::XS::encode_json );
- tied(%ha2)->decoder( \&JSON::XS::decode_json );
+ tied(%h2)->encoder( \&JSON::XS::encode_json );
+ tied(%h2)->decoder( \&JSON::XS::decode_json );
+
+ my @pairs = ( key1 => 'val1', key2 => 'val2' );
+ my @list  = ( 1, 2, 3, 4 );
 
  $h2{'foo'} = 'plain value';
  $h2{'bar'} = { @pairs };
@@ -2063,38 +2071,6 @@ Sharing a Python class is possible, starting with the 1.827 release.
 The construction is simply calling share with the module option.
 Methods are accessible via the OO interface.
 
- #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
- # Share Python class. Requires MCE::Shared 1.827 or later.
- #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-
- use strict;
- use warnings;
-
- use MCE::Hobo;
- use MCE::Shared;
-
- my $py1 = MCE::Shared->share({ module => 'My::Class' });
- my $py2 = MCE::Shared->share({ module => 'My::Class' });
-
- MCE::Shared->start;
-
- $py1->set(0, 100);
- $py2->set(1, 200);
-
- die "Ooops" unless $py1->get(0) eq '100';
- die "Ooops" unless $py2->get(1) eq '200';
-
- sub task {
-     $py1->incr(0) for 1 .. 50000;
-     $py2->incr(1) for 1 .. 50000;
- }
-
- MCE::Hobo->create(\&task) for 1 .. 3;
- MCE::Hobo->waitall;
-
- print $py1->get(0), "\n";  # 150100
- print $py2->get(1), "\n";  # 150200
-
  #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # Python class.
  #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -2134,14 +2110,8 @@ Methods are accessible via the OO interface.
 
  1;
 
-=head1 LOGGER DEMONSTRATION
-
-Often, the requirement may call for concurrent logging by many workers.
-Calling localtime or gmtime per each log entry is expensive. This uses
-the old time-stamp value until one second has elapsed.
-
  #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
- # Concurrent logger demo. Requires MCE::Shared 1.827 or later.
+ # Share Python class. Requires MCE::Shared 1.827 or later.
  #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
  use strict;
@@ -2150,29 +2120,33 @@ the old time-stamp value until one second has elapsed.
  use MCE::Hobo;
  use MCE::Shared;
 
- my $file = "log.txt";
- my $pid  = $$;
+ my $py1 = MCE::Shared->share({ module => 'My::Class' });
+ my $py2 = MCE::Shared->share({ module => 'My::Class' });
 
- my $ob = MCE::Shared->share( { module => 'My::Logger' }, path => $file )
-     or die "open error '$file': $!";
+ MCE::Shared->start;
 
- # $ob->autoflush(1);   # optional, flush writes immediately
+ $py1->set(0, 100);
+ $py2->set(1, 200);
 
- sub work {
-     my $id = shift;
-     for ( 1 .. 250_000 ) {
-         $ob->log("Hello from $id: $_");
-     }
+ die "Ooops" unless $py1->get(0) eq '100';
+ die "Ooops" unless $py2->get(1) eq '200';
+
+ sub task {
+     $py1->incr(0) for 1..50000;
+     $py2->incr(1) for 1..50000;
  }
 
- MCE::Hobo->create('work', $_) for 1 .. 4;
+ MCE::Hobo->create(\&task) for 1..3;
  MCE::Hobo->waitall;
 
- # Threads and multi-process safety for closing the handle.
+ print $py1->get(0), "\n";  # 150100
+ print $py2->get(1), "\n";  # 150200
 
- sub CLONE { $pid = 0; }
+=head1 LOGGER DEMONSTRATION
 
- END { $ob->close if $ob && $pid == $$; }
+Often, the requirement may call for concurrent logging by many workers.
+Calling localtime or gmtime per each log entry is expensive. This uses
+the old time-stamp value until one second has elapsed.
 
  #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # Logger class.
@@ -2276,12 +2250,80 @@ the old time-stamp value until one second has elapsed.
 
  1;
 
+ #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+ # Concurrent logger demo. Requires MCE::Shared 1.827 or later.
+ #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
+ use strict;
+ use warnings;
+
+ use MCE::Hobo;
+ use MCE::Shared;
+
+ my $file = "log.txt";
+ my $pid  = $$;
+
+ my $ob = MCE::Shared->share( { module => 'My::Logger' }, path => $file )
+     or die "open error '$file': $!";
+
+ # $ob->autoflush(1);   # optional, flush writes immediately
+
+ sub work {
+     my $id = shift;
+     for ( 1 .. 250_000 ) {
+         $ob->log("Hello from $id: $_");
+     }
+ }
+
+ MCE::Hobo->create('work', $_) for 1 .. 4;
+ MCE::Hobo->waitall;
+
+ # Threads and multi-process safety for closing the handle.
+
+ sub CLONE { $pid = 0; }
+
+ END { $ob->close if $ob && $pid == $$; }
+
 =head1 TIE::FILE DEMONSTRATION
 
 The following presents a concurrent L<Tie::File> demonstration. Each element
 in the array corresponds to a record in the text file. JSON, being readable,
 seems appropiate for encoding complex objects.
 
+ #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+ # Class extending Tie::File with two sugar methods.
+ # Requires MCE::Shared 1.827 or later.
+ #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
+ package My::File;
+
+ use strict;
+ use warnings;
+
+ use Tie::File;
+
+ our @ISA = 'Tie::File';
+
+ # $ob->append('string');
+
+ sub append {
+     my ($self, $key) = @_;
+     my $val = $self->FETCH($key); $val .= $_[2];
+     $self->STORE($key, $val);
+     length $val;
+ }
+
+ # $ob->incr($key);
+
+ sub incr {
+     my ( $self, $key ) = @_;
+     my $val = $self->FETCH($key); $val += 1;
+     $self->STORE($key, $val);
+     $val;
+ }
+
+ 1;
+
  #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # The MCE::Mutex module isn't needed unless IPC involves two or
  # more trips for the underlying action.
@@ -2360,40 +2402,6 @@ seems appropiate for encoding complex objects.
      }
  }
 
- #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
- # Class extending Tie::File with two sugar methods.
- # Requires MCE::Shared 1.827 or later.
- #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-
- package My::File;
-
- use strict;
- use warnings;
-
- use Tie::File;
-
- our @ISA = 'Tie::File';
-
- # $ob->append('string');
-
- sub append {
-     my ($self, $key) = @_;
-     my $val = $self->FETCH($key); $val .= $_[2];
-     $self->STORE($key, $val);
-     length $val;
- }
-
- # $ob->incr($key);
-
- sub incr {
-     my ( $self, $key ) = @_;
-     my $val = $self->FETCH($key); $val += 1;
-     $self->STORE($key, $val);
-     $val;
- }
-
- 1;
-
 =head1 REQUIREMENTS
 
 MCE::Shared requires Perl 5.10.1 or later. The L<IO::FDPass> module is highly
